Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Ingest ¶
Ingest triggers the ingestion of a file via the SDA API. Depending on the provided fields in ingestInfo: - If ingestInfo.Id is empty, it sends a POST request to /file/ingest with a JSON body containing the file path and user. - If ingestInfo.Id is set, it sends a POST request to /file/ingest with the fileid as a query parameter and no JSON body.
func SetAccession ¶
SetAccession assigns an accession ID to a file via the SDA API. Depending on the provided fields in accessionInfo: - If accessionInfo.Id is empty, it sends a POST request to /file/accession with a JSON body containing accession_id, filepath, and user. - If accessionInfo.Id is set, it sends a POST request to /file/accession with fileid and accessionid as query parameters.